@@ -49,6 +49,7 @@ class(civis_platform) <- c("CivisFuture", "future", "function")
 
 #' Evaluate an expression in Civis Platform
 #' @inheritParams future::Future
+#' @param local deprecated as of \code{civis} v3.0.1
 #' @param required_resources resources, see \code{\link{scripts_post_containers}}
 #' @param docker_image_name the image for the container script.
 #' @param docker_image_tag the tag for the Docker image.
@@ -63,7 +64,7 @@ CivisFuture <- function(expr = NULL,
                         globals = TRUE,
                         packages = NULL,
                         lazy = FALSE,
-                        local = TRUE,
+                        local = lifecycle::deprecated(),
                         gc = FALSE,
                         earlySignal = FALSE,
                         label = NULL,
@@ -72,6 +73,11 @@ CivisFuture <- function(expr = NULL,
                         docker_image_tag = "latest",
                          ...) {
 
+  if (lifecycle::is_present(local)) {
+    lifecycle::deprecate_soft(when = "3.0.1",
+                              what = "civis::CivisFuture(local)")
+  }
+  
   gp <- future::getGlobalsAndPackages(expr, envir = envir, globals = globals)
 
   ## if there are globals, assign them in envir
@@ -87,7 +93,6 @@ CivisFuture <- function(expr = NULL,
                            globals = gp$globals,
                            packages = unique(c(packages, gp$packages)),
                            lazy = lazy,
-                           local = local,
                            gc = gc,
                            earlySignal = earlySignal,
                            label = label,
@@ -163,7 +168,7 @@ cancel.CivisFuture <- function(future, ...) {
 }
 
 #' @export
-#' @describeIn CivisFuture Check if a CivisFutre has resolved
+#' @describeIn CivisFuture Check if a CivisFuture has resolved
 resolved.CivisFuture <- function(future, ...){
   if (!is.null(future$job$containerId)) {
     future$state <- scripts_get_containers_runs(id = future$job$containerId,
